# Praat vowelchart plugin
# v1.2, 2017-11-15
# http://praatpfanne.lingphon.net/
# 
# changelog
# v1.2: bug fixes


# remove old settings file
settingsFile$ = temporaryDirectory$ + "/vowelchart_settings.txt"
if fileReadable (settingsFile$)
	deleteFile: settingsFile$
endif

beginPause: "Vowelchart: Initialize"
	comment: "Display German vowelchart based on: Sendlmeier, W., & Seebode, J., 2006,"
	comment: "Formantkarten des deutschen Vokalsystems. TU Berlin."
	comment: "(https://www.kw.tu-berlin.de/fileadmin/a01311100/"
	comment: "Formantkarten_des_deutschen_Vokalsystems_01.pdf)"
	comment: ""
	boolean: "Female vowelchart", 1
	boolean: "Male vowelchart", 1
	boolean: "Space without vowels", 0
clicked = endPause: "Cancel", "OK", 2, 1
if clicked = 1
	exitScript ()
endif

endeditor
### initialize vowelchart
# basic settings
do: "Erase all"
do: "Helvetica"
Font size: 12
Select outer viewport: 0, 9, 0, 8
Colour: "Black"
Line width: 1
do: "Solid line"
# axes
Axes: 3500, 0, 1100, 0
Marks right every: 1, 50, "no", "yes", "no"
Marks right every: 1, 100, "yes", "no", "no"
Marks top every: 1, 100, "no", "yes", "no"
Marks top every: 1, 500, "yes", "no", "no"
# references
if female_vowelchart = 1 || male_vowelchart = 1
	# Paint rectangle: 0.9, 0, 3500, 1050, 1100
	# Text special: 1750, "centre", 1100, "bottom", "Times", 10, "0", "%%Praat vowelchart plugin% by Jörg Mayer (praatpfanne.lingphon.net)"
	# Text special: 1750, "centre", 1080, "bottom", "Times", 10, "0", "Standard vowelchart based on: Sendlmeier, W. & Seebode, J.: %%Formantkarten des deutschen Vokalsystems%. TU Berlin (2006)."
	Paint rectangle: 0.9, 0, 3500, 1070, 1100
	Text special: 1750, "centre", 1100, "bottom", "Times", 10, "0", "Standard vowelchart based on: Sendlmeier, W. & Seebode, J.: %%Formantkarten des deutschen Vokalsystems%. TU Berlin (2006)."
endif
Draw inner box
Text right: "yes", "##F1#"
Text top: "yes", "##F2#"
# captions
Text special: 3300, "centre", 1133, "half", "Helvetica", 10, "0", "front"
Text special: 200, "centre", 1133, "half", "Helvetica", 10, "0", "back"
Draw two-way arrow: 3180, 1133, 325, 1133
Text special: 3600, "centre", 1050, "half", "Helvetica", 10, "0", "open"
Text special: 3600, "centre", 50, "half", "Helvetica", 10, "0", "close"
Draw two-way arrow: 3600, 75, 3600, 1025

# draw female chart
if female_vowelchart = 1
	Colour: "Maroon"
	if space_without_vowels = 0
		@drawVowel: 836, 1586, "a"			; a
		@drawVowel: 896, 1517, "a\:f"		; aː
		@drawVowel: 434, 2461, "e\:f"		; eː
		@drawVowel: 608, 2040, "\ef"		; ɛ
		@drawVowel: 584, 2166, "\ef\:f"		; ɛː
		@drawVowel: 433, 2095, "\ic"		; ɪ
		@drawVowel: 302, 2533, "i\:f"		; iː
		@drawVowel: 605, 1200, "\ct"		; ɔ
		@drawVowel: 440, 889, "o\:f"		; oː
		@drawVowel: 442, 1081, "\hs"		; ʊ
		@drawVowel: 345, 956, "u\:f"		; uː
		@drawVowel: 426, 1670, "\yc"		; ʏ
		@drawVowel: 320, 1810, "y\:f"		; yː
		@drawVowel: 564, 1654, "\oe"		; œ
		@drawVowel: 440, 1605, "\o/\:f"		; øː
		@drawVowel: 572, 1763, "\sw"		; ə
	endif
	@drawSpace: 275, 2700, 750, 920, 2000, 1050, "female"
endif

# draw male chart
if male_vowelchart = 1
	Colour: "Navy"
	if space_without_vowels = 0
		@drawVowel: 694, 1372, "a"			; a
		@drawVowel: 737, 1275, "a\:f"		; aː
		@drawVowel: 348, 2126, "e\:f"		; eː
		@drawVowel: 489, 1817, "\ef"		; ɛ
		@drawVowel: 482, 1902, "\ef\:f"		; ɛː
		@drawVowel: 369, 1902, "\ic"		; ɪ
		@drawVowel: 263, 2171, "i\:f"		; iː
		@drawVowel: 537, 1074, "\ct"		; ɔ
		@drawVowel: 383, 841, "o\:f"		; oː
		@drawVowel: 391, 1010, "\hs"		; ʊ
		@drawVowel: 310, 854, "u\:f"		; uː
		@drawVowel: 373, 1543, "\yc"		; ʏ
		@drawVowel: 302, 1722, "y\:f"		; yː
		@drawVowel: 474, 1477, "\oe"		; œ
		@drawVowel: 371, 1501, "\o/\:f"		; øː
		@drawVowel: 517, 1447, "\sw"		; ə
	endif
	@drawSpace: 230, 2350, 700, 760, 1800, 950, "male"
endif

procedure drawVowel: .f1, .f2, .vowel$
	Text special: .f2, "centre", .f1, "half", "Times", 10, "0", .vowel$
endproc

procedure drawSpace: .upper, .upperLeft, .upperRight, .lower, .lowerLeft, .lowerRight, .caption$
	do: "Dotted line"
	Draw line: .upperLeft, .upper, .upperRight, .upper
	Draw line: .lowerLeft, .lower, .lowerRight, .lower
	Draw line: .upperLeft, .upper, .lowerLeft, .lower
	Draw line: .upperRight, .upper, .lowerRight, .lower
	Text special: .upperLeft, "left", .upper, "bottom", "Helvetica", 8, "0", .caption$
endproc


